#define STACK_DIRECTION_ASCENDING 1
#define STACK_DIRECTION_DESCENDING 2


/*
Various defines for values produced by `-DCFG_TARGET_*` flags. Only needs to be mutually unique
*/
#define darwin 1
#define macos 2
#define ios 3
